###############################################################################
# ManageQuiz.pm                                                               #
###############################################################################
# YaBB: Yet another Bulletin Board                                            #
# Open-Source Community Software for Webmasters                               #
# Version:        YaBB 2.7.00                                                 #
# Distributed by: http://www.yabbforum.com                                    #
# =========================================================================== #
# Copyright (c) 2000-2017 YaBB (www.yabbforum.com) - All Rights Reserved.     #
# Software by:  The YaBB Development Team                                     #
#               with assistance from the YaBB community.                      #
###############################################################################
# Written by Batchman (orig by Phyrron )                                      #
# Additional development by  Whisper68, Carsten, others)                      #
# Updated for 2.7.00 by D.A.Rorabaugh                                         #
###############################################################################
use strict;
use warnings;
our $VERSION         = '2.7.00';
our $managequizpmver = 'YaBB 2.7.00 $Revision: 1.0 $';
our ($action);
$action ||= q{};
if ( $action eq 'detailedversion' ) { return 1; }

# YaBB system ##
our (
    $action_area, $adminurl,    $iamadmin,      $vardir,
    $yymain,      $yymycharset, $yysetlocation, $yytitle,
    %admin_img,   %admin_txt,   %error_txt,     %FORM,
    %grp_nopost,  %grp_staff,   @nopostorder
);

our (
    $en_quiz,           @QuizAddGroups,       @QuizDelGroups,
    $QuizGuestTab,      $QuizHighScoreLength, $QuizMaxDecrpChars,
    $QuizMaxQuestChars, $QuizMaxTimelimit,    $QuizMinQuestions,
    @QuizModGroups,     $QuizSetTimelimit,    $QuizzesPerPage,
    %quiztxt,
);

load_language('Mods/Quiz');
load_language('Admin');

if ( !-e ("$vardir/Mods/quiz2.txt") ) {
    my $qfile = q~$QuizHighScoreLength = 5;
$QuizzesPerPage = 10;
$QuizMinQuestions = 10;
@QuizAddGroups = ();
@QuizModGroups = ();
@QuizDelGroups = ();
$QuizAddAllMembers = 1;
$QuizModifyAllMembers = 1;
$QuizDeleteAllMembers = 1;
$QuizSetTimelimit = 1;
$QuizMaxTimelimit = 120;
$QuizMaxQuestChars = 500;
$QuizMaxDecrpChars = 500;
$QuizGuestTab = 1;

1;
~;
    our ($FILE);
    fopen( 'FILE', '>>', "$vardir/Mods/quiz2.txt" );
    print {$FILE} $qfile;
    fclose('FILE');
}

sub quizsettings {
    require "$vardir/Mods/quiz2.txt";

    if ( !$iamadmin ) {
        fatal_error( $error_txt{'no_access'} );
    }

    if ( !$FORM{'QuizMaxTimelimit'} ) { $FORM{'QuizMaxTimelimit'} = 0; }
    if ( !$FORM{'QuizGuestTab'} )     { $FORM{'QuizGuestTab'}     = 0; }

    if ( !$FORM{'QuizMaxQuestChars'} ) { $FORM{'QuizMaxQuestChars'} = 500; }
    if ( !$FORM{'QuizMaxDecrpChars'} ) { $FORM{'QuizMaxDecrpChars'} = 500; }

    my $k   = 2;
    my $box = q{};
    for ( 'Global Moderator', 'Mid Moderator' ) {
        my ( $title, $stars, $starpic, $color ) = @{ $grp_staff{$_} };
        $box .= qq~<option value="$_"~;

        foreach my $line (@QuizAddGroups) {
            if ( $line eq $title ) {
                $box .= q~ selected="selected"~;
            }
        }
        $box .= qq~>$title</option>\n~;
    }
    for (@nopostorder) {
        my @groupinfo = @{ $grp_nopost{$_} };
        $box .= qq~<option value="$_"~;
        for my $line (@QuizAddGroups) {
            my ( $lineinfo, undef ) = @{ $grp_nopost{$line} };
            if ( $lineinfo eq $groupinfo[0] ) {
                $box .= q~ selected="selected"~;
            }
        }
        $box .= qq~>$groupinfo[0]</option>\n~;
        $k++;
    }
    if ( $k > 5 ) { $k = 5; }

    my $modbox = q{};
    for ( 'Global Moderator', 'Mid Moderator' ) {
        my ( $title, $stars, $starpic, $color ) = @{ $grp_staff{$_} };
        $modbox .= qq~<option value="$_"~;

        foreach my $line (@QuizModGroups) {
            if ( $line eq $_ ) {
                $modbox .= q~ selected="selected"~;
            }
        }
        $modbox .= qq~>$title</option>\n~;
    }

    for (@nopostorder) {
        my @groupinfo = @{ $grp_nopost{$_} };
        $modbox .= qq~<option value="$_"~;
        foreach my $line (@QuizModGroups) {
            my ( $lineinfo, undef ) = @{ $grp_nopost{$line} };
            if ( $lineinfo eq $groupinfo[0] ) {
                $modbox .= q~ selected="selected"~;
            }
        }
        $modbox .= qq~>$groupinfo[0]</option>~;
    }

    my $delbox = q{};
    for ( 'Global Moderator', 'Mid Moderator' ) {
        my ( $title, $stars, $starpic, $color ) = @{ $grp_staff{$_} };
        $delbox .= qq~<option value="$_"~;

        foreach my $line (@QuizDelGroups) {
            if ( $line eq $title ) {
                $delbox .= q~ selected="selected"~;
            }
        }
        $delbox .= qq~>$title</option>\n~;
    }

    for (@nopostorder) {
        my @groupinfo = @{ $grp_nopost{$_} };
        $delbox .= qq~<option value="$_"~;
        foreach my $line (@QuizDelGroups) {
            my ( $lineinfo, undef ) = @{ $grp_nopost{$line} };
            if ( $lineinfo eq $groupinfo[0] ) {
                $delbox .= q~ selected="selected"~;
            }
        }
        $delbox .= qq~>$groupinfo[0]</option>~;
    }

    $yytitle .= qq~ $quiztxt{'23'} ~;

    $yymain .= qq~
    <form action="$adminurl?action=quizsettings2" onsubmit="savealert()" method="post" name="creator" accept-charset="$yymycharset">
    <div class="bordercolor rightboxdiv">
        <table class="border-space pad-cell" style="margin-bottom: .5em;">
            <tr>
                <td class="titlebg">$admin_img{'prefimg'} <b>$quiztxt{'mod'}</b></td>
            </tr><tr>
                <td class="catbg"><span class="small">$quiztxt{'author'} <i>$quiztxt{'authorlist'}</i></span></td>
            </tr>
        </table>
    </div>
    <div class="bordercolor rightboxdiv">
        <table class="border-space pad-cell" style="margin-bottom: .5em;">
            <colgroup>
                <col style="width:40%" />
                <col style="width:60%" />
            </colgroup>
            <tr>
                <td class="titlebg" colspan="2">$admin_img{'prefimg'} <b>$quiztxt{'1'}</b></td>
            </tr><tr>
                <td class="windowbg2"><b>$quiztxt{'24'}</b></td>
                <td class="windowbg2">
                    <input type="text" name="QuizzesPerPage" size="3" value="$QuizzesPerPage" />
                </td>
            </tr><tr>
                <td class="windowbg2"><b>$quiztxt{'115'}</b></td>
                <td class="windowbg2">
                    <input type="text" name="QuizMaxDecrpChars" size="3" value="$QuizMaxDecrpChars" />
                </td>
            </tr><tr>
                <td class="windowbg2"><b>$quiztxt{'112'}</b></td>
                <td class="windowbg2">
                    <input type="text" name="QuizMaxQuestChars" size="3" value="$QuizMaxQuestChars" />
                </td>
            </tr><tr>
                <td class="windowbg2"><b>$quiztxt{'25'}</b></td>
                <td class="windowbg2">
                    <input type="text" name="QuizHighScoreLength" size="3" value="$QuizHighScoreLength" />
                </td>
            </tr><tr>
                <td class="windowbg2"><b>$quiztxt{'26'}</b></td>
                <td class="windowbg2">
                    <input type="text" name="QuizMinQuestions" size="3" value="$QuizMinQuestions" />
                </td>
            </tr><tr>
                <td class="windowbg2"><b>$quiztxt{'103'}</b></td>
                <td class="windowbg2">
                    <input type="checkbox" name="QuizSetTimelimit"${ischecked($QuizSetTimelimit)} />
                </td>
            </tr><tr>
                <td class="windowbg2"><b>$quiztxt{'104'}</b></td>
                <td class="windowbg2">
                    <input type="text" name="QuizMaxTimelimit" size="4" value="$QuizMaxTimelimit" />
                </td>
            </tr><tr>
                <td class="windowbg2"><b>$quiztxt{'116'}</b></td>
                <td class="windowbg2">
                    <input type="checkbox" name="QuizGuestTab"${ischecked($QuizGuestTab)} />
                </td>
            </tr>
        </table>
    </div>
    <div class="bordercolor rightboxdiv">
        <table class="border-space pad-cell" style="margin-bottom: .5em;">
            <tr>
                <td class="titlebg" colspan="3">
                    $admin_img{'prefimg'} <b>$quiztxt{'110'}</b>
                </td>
            </tr><tr>
                <td class="windowbg2" colspan="3">
                    <span class="small">$quiztxt{'111'}<br />$admin_txt{'14'}</span>
                </td>
            </tr><tr>
                <td class="catbg center"><b>$quiztxt{'2'}</b></td>
                <td class="catbg center"><b>$quiztxt{'27'}</b></td>
                <td class="catbg center"><b>$quiztxt{'29'}</b></td>
            </tr><tr>
                <td class="windowbg2 center">
                    <select multiple="multiple" name="QuizAddGroups" size="$k">$box</select><br />
                </td>
                <td class="windowbg2 center">
                    <select multiple="multiple" name="QuizModGroups" size="$k">$modbox</select><br />
                </td>
                <td class="windowbg2 center">
                    <select multiple="multiple" name="QuizDelGroups" size="$k">$delbox</select><br />
                </td>
            </tr>
        </table>
        </div>
        <div class="bordercolor rightboxdiv">
        <table class="border-space pad-cell" style="margin-bottom: .5em;">
            <tr>
                <th class="titlebg">$admin_img{'prefimg'} $admin_txt{'10'}</th>
            </tr><tr>
                <td class="catbg center"><input type="submit" value="$admin_txt{'10'}" /></td>
            </tr>
        </table>
    </div>
    </form>
~;

    $action_area = 'quizsettings';
    admintemplate();
    exit;
}

sub quizsettings2 {

    if ( !$iamadmin ) {
        fatal_error( $error_txt{'no_access'} );
    }

    my @onoff = qw(QuizSetTimelimit QuizGuestTab);
    foreach my $fi (@onoff) {
        no strict qw(refs);
        ${$fi} = 0;
        if ( $FORM{$fi} ) { ${$fi} = 1; }
    }
    my $QuizAddAllMembers    = 1;
    my $QuizModifyAllMembers = 1;
    my $QuizDeleteAllMembers = 1;
    if ( $FORM{'QuizAddGroups'} ) { $QuizAddAllMembers    = 0; }
    if ( $FORM{'QuizModGroups'} ) { $QuizModifyAllMembers = 0; }
    if ( $FORM{'QuizDelGroups'} ) { $QuizDeleteAllMembers = 0; }
    my $addgrp = $FORM{'QuizAddGroups'} || q{};

    if ($addgrp) {
        my @addgrp = split /,/xsm, $addgrp;
        $addgrp = join q~', '~, @addgrp;
        $addgrp = qq~'$addgrp'~;
    }
    my $modgrp = $FORM{'QuizModGroups'} || q{};
    if ($modgrp) {
        my @modgrp = split /,/xsm, $modgrp;
        $modgrp = join q~', '~, @modgrp;
        $modgrp = qq~'$modgrp'~;
    }
    my $delgrp = $FORM{'QuizDelGroups'} || q{};
    if ($delgrp) {
        my @delgrp = split /,/xsm, $delgrp;
        $delgrp = join q~', '~, @delgrp;
        $delgrp = qq~'$delgrp'~;
    }

    my $quizsettings = << "QSET";
\$QuizHighScoreLength = $FORM{'QuizHighScoreLength'};
\$QuizzesPerPage = $FORM{'QuizzesPerPage'};
\$QuizMinQuestions = $FORM{'QuizMinQuestions'};
\@QuizAddGroups = ($addgrp);
\@QuizModGroups = ($modgrp);
\@QuizDelGroups = ($delgrp);
\$QuizAddAllMembers = $QuizAddAllMembers;
\$QuizModifyAllMembers = $QuizModifyAllMembers;
\$QuizDeleteAllMembers = $QuizDeleteAllMembers; 
\$QuizSetTimelimit = $QuizSetTimelimit;
\$QuizMaxTimelimit = $FORM{'QuizMaxTimelimit'};
\$QuizMaxQuestChars = $FORM{'QuizMaxQuestChars'};
\$QuizMaxDecrpChars = $FORM{'QuizMaxDecrpChars'};
\$QuizGuestTab = $QuizGuestTab;

1;
QSET

    our ($FILE);
    fopen( 'FILE', '>', "$vardir/Mods/quiz2.txt" );
    print {$FILE} $quizsettings;
    fclose('FILE');

    $en_quiz = 2;
    if ($QuizGuestTab) {
        $en_quiz = 1;
    }

    require Admin::NewSettings;
    save_settings_to('Settings.pm');

    require "$vardir/Mods/quiz2.txt";
    write_log();
    $yysetlocation = qq~$adminurl?action=quizsettings~;
    redirectexit();
    return;
}

1;
